# vertebrate: open backbones for data architecture

**vertebrate** is a Python package that defines generic interfaces for components commonly
used in data pipelines. Starting with some abstractions for compute, storage, and data
flow, we hope to make it something like an extension of
[collections.abc](https://docs.python.org/3/library/collections.abc.html) for
data-oriented projects.
